Authors
-------

* Peter Eschler <peschler@gmail.com>
* Dirk Eschler <eschler@gmail.com>


Contributors
------------

* Carl J. Meyer
* Jaap Roes
* Bojan Mihelac
* Sébastien Fievet
* Jacek Tomaszewski
* Bruno Tavares
* And many more ...
